@@ -56,10 +56,22 @@
 #include "graph.h"
 #include "sub.h"
 #include "file_io.h"
-#ifdef __WIN32__
+#ifdef _WIN32
 #include <time.h>
 #endif
-#include "specialfunctions.h"
+// use boost special functions
+#include <boost/math/special_functions/factorials.hpp>
+#include <boost/math/special_functions/legendre.hpp>
+#include <boost/math/special_functions/laguerre.hpp>
+#include <boost/math/special_functions/hermite.hpp>
+#include <boost/math/special_functions/spherical_harmonic.hpp>
+#include <boost/math/special_functions/erf.hpp>
+#include <boost/math/special_functions/gamma.hpp>
+#include <boost/math/special_functions/bessel.hpp>
+#include <boost/math/special_functions/airy.hpp>
+#include <boost/math/special_functions/chebyshev.hpp>
+
+using namespace std;
 
 colortyp colvar;
 //
@@ -96,7 +108,7 @@ string pcode_to_string(int p){
 
 struct keyw
 {
-	char *word;
+	const char *word;
 	int index;
 	int ret,np,p[5];
 } ;
@@ -711,6 +723,30 @@ void eval_pcode_loop(GLEArrayImpl* stk, GLEPcodeList* pclist, int *pcode, int pl
 			stk->decrementSize(1);
 			setEvalStack(stk, stk->last(), boost::math::chebyshev_u( getEvalStackUnsignedInt(stk, stk->last()), getEvalStackDouble(stk, stk->last()+1)));
 			break;
+		case FN_BUILTIN_MAGIC + FN_TEST_PRINT: // test_print
+			// simple for loop that evaluates a function that is passed to it
+			//{
+			//	std::string toEval(getEvalStackStringStd(stk, stk->last()));
+			//	stk->set(stk->last(), get_global_polish()->evalGeneric(stk, toEval.c_str()));
+			//}
+			cout << endl;
+			stk->decrementSize(2);
+			{
+			std::string toEval(getEvalStackStringStd(stk, stk->last()));
+			cout << toEval << endl;
+			stringstream ss;
+			ss << "x="<<getEvalStackDouble(stk, stk->last()+1);
+			cout << ss.str().c_str()<<endl;
+			cout << getEvalStackDouble(stk, stk->last()+2)<<endl;
+			double x;
+			//get_global_polish()->eval(stk, ss.str().c_str(),&x);
+			stk->set(stk->last(), get_global_polish()->evalGeneric(stk, ss.str().c_str() ));
+			//setEvalStack(stk, stk->last(),ss.str().c_str());
+			//setEvalStack(stk, stk->last(),"print x");
+			//get_global_polish()->evalString(stk, ss.str().c_str());
+			stk->set(stk->last(), get_global_polish()->evalGeneric(stk, toEval.c_str()));
+			}
+			break;
 		case 137: /* pointx */
 			{
 				GLEPoint pt;
@@ -822,7 +858,7 @@ void eval_pcode_loop(GLEArrayImpl* stk, GLEPcodeList* pclist, int *pcode, int pl
 				GLERC<GLEString> needle(getEvalStackGLEString(stk, stk->last() - 1));
 				GLEString* hayStack(getEvalStackGLEString(stk, stk->last() - 2));
 				validateArrayIndexRange(from, 1, hayStack->length());
-				stk->decrementSize(1);
+				stk->decrementSize(2);
 				setEvalStack(stk, stk->last(), hayStack->find(needle.get(), hayStack->toStringIndex(from)) + 1);
 			}
 			break;
@@ -1077,7 +1113,6 @@ void eval_pcode_loop(GLEArrayImpl* stk, GLEPcodeList* pclist, int *pcode, int pl
 				stringstream ss;
 				ss <<"unrecognized byte code expression " <<pcode[c];
 				g_throw_parser_error(ss.str());
-
 			}
 		break;
 	  }
@@ -1216,7 +1251,7 @@ void debug_polish(int *pcode,int *zcp)
 	}
 	plen = *(pcode+*(cp));
 	gprint("Expression length %d current point %d \n",plen,(int) *cp);
-	if (plen>1000) gprint("Expession is suspiciously int %d \n",plen);
+	if (plen>1000) gprint("Expression is suspiciously int %d \n",plen);
 	for (c=(*cp)+1;(c-*cp)<=plen;c++) {
 	  cde = *(pcode+c);
 	  gprint("Code=%d ",cde);
