@@ -56,6 +56,8 @@
 
 #include <memory>
 
+using namespace std;
+
 bool GLEReadFileBinaryGZIP(const string& name, std::vector<GLEBYTE>* contents);
 
 RefCountObject::RefCountObject() {
@@ -212,7 +214,7 @@ void GLEZData::read(const string& fname) {
 	string expanded(GLEExpandEnvironmentVariables(fname));
 	validate_file_name(expanded, false);
 	TokenizerLanguage lang;
-	std::auto_ptr<Tokenizer> tokens;
+	std::unique_ptr<Tokenizer> tokens;
 	std::vector<GLEBYTE> contents;
 	if (str_i_ends_with(expanded, ".gz")) {
 		if (GLEReadFileBinaryGZIP(expanded, &contents)) {
