@@ -57,6 +57,8 @@
 #include "surface/gsurface.h"
 #include "run.h"
 
+using namespace std;
+
 GLEParser* g_parser;
 
 extern GLESubMap g_Subroutines;
@@ -350,7 +352,7 @@ void GLEParser::polish(GLEPcode& pcode, int *rtype) {
 	Tokenizer* tokens = getTokens();
 	string& expr = tokens->next_multilevel_token();
 	int pos = tokens->token_pos_col();
-	// cout << "pos = " << pos << endl;
+	//cout << "pos = " << pos << endl;
 	try {
 		//cout << "Polish: '" << expr << "'" << endl;
 		m_polish->internalPolish(expr.c_str(), pcode, rtype);
@@ -697,7 +699,7 @@ int GLEParser::get_optional(OPKEY lkey, GLEPcode& pcode) {
 	get_key_info(lkey, &count, &width);
 	// the location in the pcode tells what option it is, must remember
 	// zero all the optional parameters.
-	// puts zero in for each option wheather it is there or not
+	// puts zero in for each option whether it is there or not
 	int plen = pcode.size();
 	for (int i = 0; i < width+1; i++) {
 		pcode.addInt(0);
@@ -960,7 +962,7 @@ void GLEParser::get_color(GLEPcode& pcode) {
 }
 
 int get_marker_string(const string& marker, IThrowsError* error) {
-	/* if 0, maybe its a user defined marker, ie a subroutine */
+	/* if 0, maybe it's a user-defined marker, i.e. a subroutine */
 	/* Use -ve to signify subroutine instead of normal marker */
 	int mark_idx = 0;
 	for (int i = 0; i < nmark; i++) {
@@ -2033,6 +2035,10 @@ void GLEParser::passt(GLESourceLine &SLine, GLEPcode& pcode) {
 			  case GLE_KW_SLEEP:
 				get_exp(pcode);
 				break;
+			  case GLE_KW_SWAP:
+				get_var(pcode);
+				get_var(pcode);
+				break;
 			  default:
 				throw error("unrecognised command {"+first+"}");
 			}
