@@ -50,6 +50,8 @@
 
 #include <set>
 
+using namespace std;
+
 #define true (!false)
 #define false 0
 
@@ -701,6 +703,10 @@ char* var_get_name(int var) {
 	return getVarsInstance()->getName(var);
 }
 
+int var_get_type(int var) {
+	return var_type(getVarsInstance()->getName(var));
+}
+
 void var_nlocal(int *l) {
 	*l = getVarsInstance()->getNbLocal();
 }
