@@ -26,6 +26,8 @@
 #include "settings.h"
 #include "consolewindow.h"
 
+using namespace std;
+
 EvaluatorDialog::EvaluatorDialog(GLEMainWindow *parent) : QDialog(parent)
 {
 	mainWin = parent;
@@ -435,7 +437,7 @@ void SoftwareLocateDialogue::locateManual() {
 	cursor.movePosition(QTextCursor::End);
 	browser->setTextCursor(cursor);
 	browser->insertPlainText(tr("\n"));
-	// don't use stock dialog; otherwise it's impossible to select a framework on MacOS/X
+	// don't use stock dialog; otherwise it's impossible to select a framework on macOS
 	QFileDialog dialog(this, tr("Locate the GhostScript library"), "/", QGLE::libraryFilter());
 	dialog.setFileMode(QFileDialog::AnyFile);
 	if (dialog.exec()) {
